@@ -1,6 +1,6 @@
 /** - C source file -
  *
- * Copyright (C) 2009-2010 ABINIT Group (Damien Caliste)
+ * Copyright (C) 2009-2012 ABINIT Group (Damien Caliste)
  *
  * This file is part of the ABINIT software package. For license information,
  * please see the COPYING file in the top-level directory of the ABINIT source
@@ -19,7 +19,7 @@
 
 /* Fortran interface. */
 void VARS_NAME(new_from_file,NEW_FROM_FILE)
-  (int *dt, const char *filename, int *len);
+     (int *dt, const char *filename, int *len, const char *pseudo, int *npsp);
 void VARS_NAME(new_from_string,NEW_FROM_STRING) 
   (int *dt, const char *string, int *len);
 void VARS_NAME(free,FREE)            
@@ -46,12 +46,47 @@ Ab6InvarsTypes ab6_invars_get_type_from_id(Ab6InvarsIds id)
 
 Ab6Invars* ab6_invars_new_from_file(const char *filename)
 {
-  int n;
+  int n, npsp;
   Ab6Invars *dt, tmpDt;
+  char buf[8] = "        ";
   
   n = strlen(filename);
+  npsp = 0;
+
+  VARS_CALL(new_from_file, NEW_FROM_FILE, &tmpDt, filename, &n, buf, &npsp);
+  if (tmpDt > 0)
+    {
+      dt = malloc(sizeof(Ab6Invars));
+      *dt = tmpDt;
+    }
+  else
+    dt = (Ab6Invars*)0;
+  return dt;
+}
+Ab6Invars* ab6_invars_new_from_file_with_pseudo(const char *filename, const char **pspfiles)
+{
+  int n, npsp;
+  Ab6Invars *dt, tmpDt;
+  char *psp;
+  size_t i, len;
   
-  VARS_CALL(new_from_file, NEW_FROM_FILE, &tmpDt, filename, &n);
+  n = strlen(filename);
+  npsp = 0;
+  if (pspfiles)
+    for (npsp = 0; pspfiles[npsp]; npsp++);
+
+  if (npsp)
+    {
+      len = sizeof(char) * npsp * 264;
+      psp = malloc(len);
+      for (npsp = 0; pspfiles[npsp]; npsp++)
+        strncpy(psp + 264 * npsp, pspfiles[npsp], 264);
+      for (i = 0; i < len; i++)
+        if (psp[i] == '\0')
+          psp[i] = ' ';
+    }
+  
+  VARS_CALL(new_from_file, NEW_FROM_FILE, &tmpDt, filename, &n, psp, &npsp);
   if (tmpDt > 0)
     {
       dt = malloc(sizeof(Ab6Invars));
