@@ -1,7 +1,12 @@
 #include <config.h>
 
 #include <Python.h>
+
 #include <structmember.h>
+#include <string.h>
+#include <stdlib.h>
+
+/** #define HAVE_NUMPY **/
 
 #ifdef HAVE_NUMPY
 #include <numpy/arrayobject.h>
@@ -21,6 +26,15 @@
 
 #include "ab6_invars_py.h"
 
+
+/* proptotypes for the replacement functions */
+static char *
+my_strndup (char const *s, size_t n);
+
+static size_t
+my_strnlen (const char *string, size_t maxlen);
+
+
 /* The abinit module provides:
    - a new class dtsets, with an array of datasets.
 */
@@ -395,7 +409,7 @@ void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500])
 {
   char *buf, *ptError, *ptInvars0, *ptInstrng, *ptSize, *pt;
 
-  buf = strndup(message, 500);
+  buf = my_strndup(message, 500);
   pt = buf + 498;
 /*   while (buf[0] == ' ') buf++; */
   while (pt[0] == ' ' || pt[0] == '\0') pt--;
@@ -432,3 +446,37 @@ void FC_FUNC(leave_new, LEAVE_NEW)()
 void FC_FUNC(timab, TIMAB)(int *nn, int *option, double tottim[2])
 {
 }
+
+/* A replacement function, for systems that lack strndup.
+
+   Copyright (C) 1996, 1997, 1998, 2001, 2002, 2003, 2005, 2006, 2007, 2009,
+   2010 Free Software Foundation, Inc.
+*/
+
+char *
+my_strndup (char const *s, size_t n)
+{
+  size_t len = my_strnlen (s, n);
+  char *new = malloc (len + 1);
+
+  if (new == NULL)
+    return NULL;
+
+  new[len] = '\0';
+  return memcpy (new, s, len);
+}
+
+
+/* A replacement function, for systems that lack strnlen.
+   Copyright (C) 2005, 2006, 2007, 2009, 2010 Free Software Foundation, Inc.
+   Written by Simon Josefsson.*/
+
+/* Find the length of STRING, but scan at most MAXLEN characters.
+   If no '\0' terminator is found in that many characters, return MAXLEN.  */
+
+size_t
+my_strnlen (const char *string, size_t maxlen)
+{
+  const char *end = memchr (string, '\0', maxlen);
+  return end ? (size_t) (end - string) : maxlen;
+}
