@@ -4,7 +4,7 @@
 # Object: compare 2 output files from ABINIT line by line with arithmetic
 # comparisons of floating point substrings
 #
-# Copyright (C) 1999-2010 ABINIT group (LSi,XG)
+# Copyright (C) 1999-2012 ABINIT group (LSi,XG)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -22,8 +22,11 @@
 # must be bigger than the tolerance.
 #
 # Some special characters at the beginning of lines require a different handling:
-# +	mark lines as different regardless to their content
 # -	mark lines as same regardless to their content (i. e. ignore lines)
+#     (can be be present in the 2 files or not, but must begin with -)
+# _ mark lines as same regardless to their content
+#     (must be present in the 2 files, but can begin with _ in only one of them)
+# +	mark lines as different regardless to their content
 # ,	handle as + with -include option and as - with -ignore option
 # P	handle as + with -includeP option and as - with -ignoreP option
 # %	floating point comparisons are done with a tolerance of 1.01e-2
@@ -103,18 +106,18 @@ while (1) {
     }
   }
 if ($include + $ignore >= 2) {
-  print 'Error: -ignore and -include are mutually exclusive';
-  print "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
+  print STDERR 'Error: -ignore and -include are mutually exclusive';
+  print STDERR "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
   &summary(12);
   }
 if ($includeP + $ignoreP >= 2) {
-  print 'Error: -ignoreP and -includeP are mutually exclusive';
-  print "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
+  print STDERR 'Error: -ignoreP and -includeP are mutually exclusive';
+  print STDERR "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
   &summary(12);
   }
 if ($ridiculous + $easy + $medium >= 2) {
-  print 'Error: -ridiculous, -easy and -medium are mutually exclusive';
-  print "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
+  print STDERR 'Error: -ridiculous, -easy and -medium are mutually exclusive';
+  print STDERR "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
   &summary(12);
   }
 # set up default tolerance
@@ -124,23 +127,26 @@ $defaulttol= 1.01e-5 if ($easy == 1);          # easy value
 $defaulttol= 1.01e-2 if ($ridiculous == 1);    # ridiculous value
 $maxAbsDif = 0.0e0;
 $maxRelDif = 0.0e0;
+# counting all the differences independent of $tolerance
+$maxAbsDif2 = 0.0e0;
+$maxRelDif2 = 0.0e0;
 # check file identifications
 $in1 = $ARGV[$argptr];
 $in2 = $ARGV[$argptr+1];
 $label = $ARGV[$argptr+2];
 if ($in1 eq '' || $in2 eq '') {
-  print "Missing input file(s)";
-  print "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
+  print STDERR "Missing input file(s)";
+  print STDERR "Usage is: fldiff [-context] [ -ignore | -include ] [ -ignoreP | -includeP ] [ -easy | -medium | -ridiculous ] file1 file2 [label] \n";
   &summary(12);
   }
 $rc = open(FILEIN1,"<$in1");
 if ($rc eq '') {
-  print "Unable to open input file $in1\n";
+  print STDERR "Unable to open input file $in1\n";
   &summary(16);
   }
 $rc = open(FILEIN2,"<$in2");
 if ($rc eq '') {
-  print "Unable to open input file $in2\n";
+  print STDERR "Unable to open input file $in2\n";
   &summary(16);
   }
 # read both files a first time and check consistency
@@ -151,6 +157,7 @@ while (1) {
     $lnm1 ++;		# bump line counter
     $ldc1 = substr($lin1,0,1);	# leading character
     $ldc1 = ' ' if ($ldc1 eq "\n" || $ldc1 eq "\r");	# handle null lines as blank
+    $ldc1 = ' ' if ($ldc1 eq "_");	# treat lines beginning with "_" as normal
     last if ($ldc1 ne '-' && $ldc1 ne 'P');	# read until not to be ignored line
     $ign1 ++;		# bump ignored lines counter
     }
@@ -158,6 +165,7 @@ while (1) {
     $lnm2 ++;		# bump line counter
     $ldc2 = substr($lin2,0,1);	# leading character
     $ldc2 = ' ' if ($ldc2 eq "\n" || $ldc2 eq "\r");	# handle null lines as blank
+    $ldc2 = ' ' if ($ldc2 eq "_");	# treat lines beginning with "_" as normal
     last if ($ldc2 ne '-' && $ldc2 ne 'P');	# read until not to be ignored line
     $ign2 ++;		# bump ignored lines counter
     }
@@ -167,17 +175,17 @@ while (1) {
 # end of file should occur on both files simultanously
 # significant lines should correspond 1 by 1
     if ($lin1 ne $lin2 || $lct1 != $lct2) {
-      print "The diff analysis cannot be done : the number of lines to be analysed differ.";
-      print "File 1: $lnm1 lines, $ign1 ignored";
-      print "File 2: $lnm2 lines, $ign2 ignored\n";
+      print STDERR "The diff analysis cannot be done : the number of lines to be analysed differ.";
+      print STDERR "File $in1: $lnm1 lines, $ign1 ignored";
+      print STDERR "File $in2: $lnm2 lines, $ign2 ignored\n";
       &summary(32);
       }
     last;
     }
   if ($ldc1 ne $ldc2) {
-    print "The diff analysis cannot be pursued : the leading characters differ.";
-    print "File 1, line $lnm1, $ign1 ignored, character:$ldc1";
-    print "File 2, line $lnm2, $ign2 ignored, character:$ldc2\n";
+    print STDERR "The diff analysis cannot be pursued : the leading characters differ.";
+    print STDERR "File $in1, line $lnm1, $ign1 ignored, character:$ldc1";
+    print STDERR "File $in2, line $lnm2, $ign2 ignored, character:$ldc2\n";
     &summary(36);
     }
   }
@@ -186,12 +194,12 @@ close(FILEIN1);
 close(FILEIN2);
 $rc = open(FILEIN1,"<$in1");
 if ($rc eq '') {
-  print "Unable to open input file $in1\n";
+  print STDERR "Unable to open input file $in1\n";
   &summary(16);
   }
 $rc = open(FILEIN2,"<$in2");
 if ($rc eq '') {
-  print "Unable to open input file $in2\n";
+  print STDERR "Unable to open input file $in2\n";
   &summary(16);
   }
 #
@@ -214,8 +222,8 @@ while (1) {
     last if ($ldc2 ne '-' && $ldc2 ne 'P');	# read until not to be ignored line
     }
   last if($lin1 eq '' && $lin2 eq ''); # end of both files
-  if ($ldc1 ne $ldc2) {		# never be too carefull
-    print "Internal error at lines $lnm1 $lnm2";
+  if ($ldc1 ne $ldc2 && $ldc1 ne '_' && $ldc2 ne '_') {		# never be too carefull
+    print STDERR "Internal error at lines $lnm1 $lnm2";
     &summary(96);
     }
 # YP: ignore differences caused by MPI extra output
@@ -248,6 +256,10 @@ while (1) {
     $same = 1 if ($ignoreP == 1);        # handle as same and ignore if -ignoreP
     $same = 0 if ($includeP == 1);       # handle as different if -includeP
     }
+# _ command character
+  elsif($ldc1 eq '_' || $ldc2 eq '_') {
+    $same = 1;		# handle lines as same
+    }
 # other command: compare lines field by field, ignoring imbedded blanks
   else {
     @field1 = split(' ',substr($lin1,1));	# parse line into array
@@ -333,6 +345,33 @@ while (1) {
               $absnum1=$fltnum1 ;
               $absnum1 = -$absnum1 if ($absnum1 < 0);
               $sumflt = $absnum1 + $absnum;
+# counting all differences independent of $tolerance (GAF)
+	      if($difflt > 0.0e0) {
+#		  print '---BEGIN Line1=',$lnm1,'Line2=',$lnm2,'Field=',$i;
+#		  print '$maxAbsDif2',$maxAbsDif2;
+#		  print '$maxRelDif2',$maxRelDif2;
+		  if ($difflt > $maxAbsDif2) {
+		      $maxAbsDif2 = $difflt;
+		  }
+		  if ($sumflt > 0.0e0) {
+#		      print 'DIFFLT',$difflt,'=',$fltnum1,'-',$fltnum;
+#		      print 'SUMFLT',$sumflt;
+#		      print '$difflt / $sumflt', $difflt,' / ',$sumflt;
+		      if ($difflt*$sumflt > 0.0e0) {
+			  $diffltrel2 = $difflt / $sumflt;
+#			  print 'Setting: $diffltrel2',$diffltrel2
+		      }
+		      if ($diffltrel2 > $maxRelDif2) {
+#			  print 'Line1=',$lnm1,'Line2=',$lnm2,'Field=',$i,'DIFFTREL2',$difftrel2;
+#			  print 'Line1=',$lnm1,'Line2=',$lnm2,'Field=',$i,'MAXRELDIF2',$maxRelDIF2;
+			  $maxRelDif2 = $diffltrel2;
+		      }
+		  }
+#		  print '$maxAbsDif2',$maxAbsDif2;
+#		  print '$maxRelDif2',$maxRelDif2;
+#		  print '---END Line1=',$lnm1,'Line2=',$lnm2,'Field=',$i;
+	      }
+# counting only differences inside tolerance
               if ( $difflt > $tolerance && $difflt > $tolerance * $sumflt ) {
 # Error: both tolerance criteria exceeded
                 print 'DBG flttoler',$lnm1,$i if($debug >= 1);
@@ -463,6 +502,23 @@ sub strfltrem {
 #
 sub summary {
   local ($exitcode) = @_;
+  if ($maxAbsDif2>0){
+      $IncrMaxAbsDif2=$maxAbsDif2+0.001*10**int(log($maxAbsDif2)/log(10));
+  }
+  else
+  {
+      $IncrMaxAbsDif2=$maxAbsDif2
+  }
+  if ($maxRelDif2>0){
+      $IncrMaxRelDif2=$maxRelDif2+0.001*10**int(log($maxRelDif2)/log(10));
+  }
+  else
+  {
+      $IncrMaxRelDif2=$maxRelDif2
+  }
+
+#  print STDERR "$label tolnlines= $diffcntfl tolabs= $maxAbsDif2 tolrel= $maxRelDif2";
+  #printf STDERR "$label tolnlines= %2d tolabs= %.3e tolrel= %.3e\n",$diffcnt,$IncrMaxAbsDif2,$IncrMaxRelDif2;
 # this routine will print a short summary of differences and exit with the code
 # note that most shells only recognize integer numbers as exit codes
   if ($exitcode != 0) {
@@ -474,6 +530,7 @@ sub summary {
     exit 0;
     }
 #
-  print "Summary $label : different lines= $diffcnt , max discrepancies absolute= $maxAbsDif (l.$linAbsDif), relative= $maxRelDif (l.$linRelDif)";
+#  print "Summary $label : different lines= $diffcnt , max discrepancies absolute= $maxAbsDif (l.$linAbsDif), relative= $maxRelDif (l.$linRelDif)";
+  printf "Summary $label : different lines= %d , max abs_diff= %.3e (l.%d), max rel_diff= %.3e (l.%d)", $diffcnt,$maxAbsDif,$linAbsDif,$maxRelDif,$linRelDif;
   exit 4;
   }
