@@ -2,7 +2,7 @@
 # This script runs one abinit built-in test in background mode while
 # periodically displaying the status file till the end of the process.
 
-# Copyright (C) 1999-2010 ABINIT group (LSi,XG)
+# Copyright (C) 1999-2012 ABINIT group (LSi,XG)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~ABINIT/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -19,12 +19,12 @@
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
 #
-$DELAY = 2;		# delay in seconds between 2 verifications of the STATUS file
+$DELAY = 3;		# delay in seconds between 2 verifications of the STATUS file
 $NCHECKS = 10;		# max number of times to check
 $MAXLOOP = '50';	# maximum count for STATUS file checking loop
-%PspFiles=('in_1','01h.pspgth',
-	 'in_2','70yb.pspnc',
-	 'in_3','01h.pspgth:04be.pspgth',
+%PspFiles=('in_fast','01h.pspgth',
+	 'in_v1','70yb.pspnc',
+	 'in_v5','01h.pspgth:04be.pspgth',
 	 'in_bigdft','01h.pspgth',
 	 'in_etsf_io','20ca.paw',
 	 'in_libxc','83bi.psphgh',
@@ -33,7 +33,7 @@ $MAXLOOP = '50';	# maximum count for STATUS file checking loop
 $debug = 0;		# Debug level ???
 if ($ARGV[1] eq '') {
   print 'Missing argument';
-	print "Usage is: run-basic-tests machine_name [ in_1 | in_2 | in_3 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir";
+	print "Usage is: run-basic-tests machine_name [ in_fast | in_v1 | in_v5 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir";
 	exit 16;
 	}
 $MACH = $ARGV[0];
@@ -69,6 +69,7 @@ if ($OSname eq 'Windows_NT') {	# check Windows environmental variable
 # drop version code from kernel name
 # by JMB : add support of mixed env cygwin + mingw compilation : MINGW64_NT
     $UNkernel = 'MINGW64_NT' if ( $UNkernel eq 'CYGWIN_NT-6.1-WOW64');
+    $UNkernel = 'MINGW64_NT' if ( $UNkernel eq 'CYGWIN_NT-5.2-WOW64');
     $UNkernel =~ m/(.*)(-)([0-9]+\.[0-9]+)/;
     $UNkernel = $1 if ($& ne '');
     if ($OStype eq '' && $UNkernel eq '') {
@@ -149,12 +150,12 @@ else {
     exit (99);
     }
 # make sure "files" file exist
-$inputfile = &transpath("$srcDir/tests/built-in/Input/test$TestN.in");
+$inputfile = &transpath("$srcDir/built-in/Input/test$TestN.in");
 print "$OStype $SLASH $SUFXstyle $inputfile" if ($debug >=2);
 if (! -e &transpath("$inputfile") ) {
 	print "Invalid test number: $TestN";
 	print "Expected input file $inputfile not found";
-	print "Usage is: run-basic-tests machine_name [ in_1 | in_2 | in_3 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir ";
+	print "Usage is: run-basic-tests machine_name [ in_fast | in_v1 | in_v5 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir ";
 	exit (8);
 	}
 #
@@ -196,9 +197,9 @@ else {
   }
 unlink($statfile) if (-e $statfile);
 # Write input files for test
-system("$COPY_COMMAND ".&transpath("$srcDir/tests/built-in/Input/test$TestN.in")." test$TestN.in");
+system("$COPY_COMMAND ".&transpath("$srcDir/built-in/Input/test$TestN.in")." test$TestN.in");
 if ($TestN eq 'in_wannier90') {
-  system("$COPY_COMMAND ".&transpath("$srcDir/tests/built-in/Input/testin_wannier90o_w90.win")." testin_wannier90o_w90.win");
+  system("$COPY_COMMAND ".&transpath("$srcDir/built-in/Input/testin_wannier90o_w90.win")." testin_wannier90o_w90.win");
   }
 # Write abinit.files for test
 $rc = open (FILES,">test$TestN.files");
@@ -211,19 +212,19 @@ print FILES "test$TestN";
 print "Psp files: @PsP" if ($debug >=1);
 
 if( $UNkernel eq 'MINGW64_NT') {
-   print FILES &transpath("/cygwin$srcDir/tests/Psps_for_tests/$PsP[0]");
-   print FILES &transpath("/cygwin$srcDir/tests/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
+   print FILES &transpath("/cygwin$srcDir/Psps_for_tests/$PsP[0]");
+   print FILES &transpath("/cygwin$srcDir/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
 } else {
-   print FILES &transpath("$srcDir/tests/Psps_for_tests/$PsP[0]");
-   print FILES &transpath("$srcDir/tests/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
+   print FILES &transpath("$srcDir/Psps_for_tests/$PsP[0]");
+   print FILES &transpath("$srcDir/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
 }
 
-print FILES &transpath("$srcDir/tests/Psps_for_tests/$PsP[0]");
-print FILES &transpath("$srcDir/tests/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
+print FILES &transpath("$srcDir/Psps_for_tests/$PsP[0]");
+print FILES &transpath("$srcDir/Psps_for_tests/$PsP[1]") if ($PsP[1] ne '');
 close (FILES);
 # abinit will be started through a dotest perl script
 # this is necessary under DOS/Windows because of file redirections
-$cmd = $PRLPFX.&transpath("$srcDir/tests/Scripts/run-basic-dotest$PLSUFX")." $TestN $ENDtest $SLASH $SUFXstyle $BGSUFX";
+$cmd = $PRLPFX.&transpath("$srcDir/Scripts/run-basic-dotest$PLSUFX")." $TestN $ENDtest $SLASH $SUFXstyle $BGSUFX";
 print $cmd if ($debug >= 2);
 $rc = system($cmd);
 die "Error $rc starting run-basic-dotest" if ($rc != 0);
