@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2005-2010 ABINIT Group (Yann Pouillon)
+# Copyright (C) 2005-2012 ABINIT Group (Yann Pouillon)
 #
 # This file is part of the ABINIT software package. For license information,
 # please see the COPYING file in the top-level directory of the ABINIT source
@@ -52,15 +52,15 @@ EOF
 
 case "${test_number}" in
 
- in_1)
+ in_fast)
   echo "${abinit_pspdir}/01h.pspgth" >> "${my_output}.files"
   ;;
 
- in_2)
+ in_v1)
   echo "${abinit_pspdir}/70yb.pspnc" >> "${my_output}.files"
   ;;
 
- in_3)
+ in_v5)
   echo "${abinit_pspdir}/01h.pspgth" >> "${my_output}.files"
   echo "${abinit_pspdir}/04be.pspgth" >> "${my_output}.files"
   ;;
