@@ -1,7 +1,7 @@
 # Script for running various tests of the parallel version of abinit
 # Before running this script, read README in this directory.
 
-# Copyright (C) 1998-2010 ABINIT group (XG,LSi)
+# Copyright (C) 1998-2012 ABINIT group (XG,LSi)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -10,7 +10,7 @@
 # Because of some execution problems, the script executes only one
 # 'test' at a time (See the keyword 'HERE'), meaning that only one
 # input file is considered, for different cases, from pure sequential
-# to parallel with 10 processors.
+# to parallel with 32 processors.
 
 # Also, only selected machine names are allowed, see the keyword 'MACH_LIST'
 #
@@ -54,15 +54,17 @@ do "$top_testdir/Scripts/reportdiff.pl";
 # This is required for nightly builds, because e.g. binaries built
 # with ifort 10.0 make the process hang forever when they crash.
 $timeout = $ENV{'timeout'};
+$timeout = '0';
 $timeout = '0' if ($timeout eq '');
 
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
 #
-@MachList=('t3e','sgi','tux','vpp','compaq_es40','magerit','sr8k','mpd','sun','test','spinoza','fock','max','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)','cea','chpit-intel11','chpit-gcc44','testf-gcc43','testf-gcc44','bigmac','bigmac-g95','bigmac-gcc44','green','green-gcc42','green-g95','config','coba2-gcc44','coba2-intel','buda_mpich2','buda-gcc43_openmpi','buda-gcc44_openmpi','buda-gcc45_openmpi', 'buda-intel11', 'inca', 'shiva', 'ibm6_mpich2', 'ibm6_openmpi','ibm6', 'win32_mpich2','littlebuda');
+@MachList=('t3e','sgi','tux','vpp','compaq_es40','magerit','sr8k','mpd','sun','test','spinoza','fock','max','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)','cea','chpit-intel11','chpit-gcc44','testf-gcc43','testf-gcc44','bigmac','bigmac-g95','bigmac-gcc44','green','green-gcc42','green-g95','config','coba2-gcc44','coba2-intel','coba2-open64','buda_mpich2','buda-gcc43_openmpi','buda-gcc44_openmpi','buda-gcc45_openmpi', 'buda-intel11', 'inca', 'shiva', 'ibm6_mpich2', 'ibm6_openmpi','ibm6', 'win32_mpich2','littlebuda','green-intel11', 'ktulu','woopy', 'toum', 'hmem','max2','max2-openmpi','max2-open64','max2-ifort12','tikal-openmp','tikal','toum-ifort12','cronos','tikal-ifort12','vishnu','petrus','bigmac-gcc47','tikal-pgi','yquem');
 @CompiloList = ('g95','pgi','gcc41','gcc42','gcc43','pathscale','intel','intel10','open64','sun');
-@Cases = ('1','2','4','10');
-$debug = 2;
+@Cases = ('1','2','4','10','24','32');
+@Sets = ('A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','AA','AB','AC','AD','AE','AF','AG','AH','AI','AJ','AK','AL','AM','AN','AO','AP','AQ','AR','AS','AT','AU','AV','AW','AX','AY','AZ','dfpt_01','dfpt_02','dfpt_03','dfpt_04');
+$debug = 1;
 $POE = 0;
 # Check whether a machine name is provided
 if ($#ARGV < 1) {
@@ -93,9 +95,16 @@ if ($rc == 0) {
 	chop $_;
 	($LINonWIN,$wd2,$wd3,$wd4,$wd5,$wd6,$wd7,$wd8,$wd9) = split(' ',$_);
 	close IP;
+  	$LINonWIN = 'MINGW64_NT' if ( $LINonWIN eq 'CYGWIN_NT-6.1-WOW64');
+  	$LINonWIN = 'MINGW64_NT' if ( $LINonWIN eq 'CYGWIN_NT-5.2-WOW64');
 	$LINonWIN =~ m/(.*)(-)([0-9]+\.[0-9]+)/;
 	$LINonWIN = $1 if ($& ne '');	# cleanup version number and keep plain uname
 	if ($OSname eq 'Windows_NT' && $LINonWIN eq 'CYGWIN_NT') {
+# cygwin shell works like a normal unix system
+		$PERLSLASH = $UNIXSLASH;	# subdirectory delimitor for perl file paths
+		$PLSUFX = '.pl';		# no special suffix for perl script
+		}
+	if ($OSname eq 'Windows_NT' && $LINonWIN eq 'MINGW64_NT') {
 # cygwin shell works like a normal unix system
 		$PERLSLASH = $UNIXSLASH;	# subdirectory delimitor for perl file paths
 		$PLSUFX = '.pl';		# no special suffix for perl script
@@ -133,18 +142,19 @@ else {
 	exit 99;
 	}
 
+# by JMB : add support of mixed env cygwin + mingw compilation : MINGW64_NT
+$CYGWIN = $LINonWIN eq 'MINGW64_NT' ? '/cygwin' : '';
 
 if ($timeout eq '0') {
   $timeout_cmd = '';
   }
 else {
-  $timeout_cmd = &perlpath("$nightly_bindir/timeout$XSUFX")." $timeout ";
+  $timeout_cmd = &perlpath("$CYGWIN/$nightly_bindir/timeout$XSUFX")." $timeout ";
 }
-$CODE_SEQ = &perlpath("$abinit_bindir/abinit$XSUFX");	# codename for sequential version
-$CODE_PAR = &perlpath("$abinit_bindir/abinit$XSUFX");	# codename for parallel version
-$PSPS = &transpath($abinit_pspdir);		# pseudopotential directory  
-# Set a default for the second and third pseudopotentials (the latter is needed
-# only for the tests number L)
+$CODE_SEQ = &perlpath("$CYGWIN/$abinit_bindir/abinit$XSUFX");	# codename for sequential version
+$CODE_PAR = &perlpath("$CYGWIN/$abinit_bindir/abinit$XSUFX");	# codename for parallel version
+$PSPS = &transpath("$CYGWIN$abinit_pspdir");		# pseudopotential directory  
+# Set a default for the second and third pseudopotentials 
 $PSP2 = &transpath("$PSPS/33as.SGS_mod");
 $PSP3 = &transpath("$PSPS/33as.SGS_mod");
 $FLDIFF = &perlpath("$PERL $abinit_rundir/fldiff.pl");	# fldiff script in utilities directory
@@ -161,12 +171,14 @@ $TESTDIR = $ARGV[1];
 $LAM = 0;
 $MPICH = 0;
 # List the set of cases for each machine (mask the second characteristics
-# of tests, that may be 0, 1, 2, 4, 10 ; 0, 1 and 2 are always allowed)
+# of tests, that may be 0, 1, 2, 4, 10, 24 or 32 ; 0, 1 and 2 are always allowed)
 $CASE0 = 1;
 $CASE1 = 1;
 $CASE2 = 1;
 $CASE4 = 1;
 $CASE10 = 1;
+$CASE24 = 1;
+$CASE32 = 1;
 # However, the list of cases depend on the test
 #-----------------------------------
 # For the t3e in berkeley and Garching
@@ -282,7 +294,7 @@ elsif ($MACH eq 'sr8k' || $MACH eq 'mpd') {
 	}
 # 
 elsif ($MACH eq 'cea') {
-  $MPIRUN_NP = 'cea_mprun -p parallele_128 -n ';
+  $MPIRUN_NP = 'cea_mprun -n ';
 	}
 #-----------------------------------
 # For the Sun sunfire 2 proc
@@ -332,25 +344,10 @@ elsif ($MACH =~ /^sleepy-?(.*)/) {
 elsif ($MACH eq 'bigmac') {
   $MPICH = 2;
   $OPENMPI = 1;
-#  $MPICH_DIR = '/opt/local/lib/openmpi/bin';
   $MPICH_DIR = '/opt/local/openmpi-gcc43_m64/bin';
   $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
-  $MACH0='bigmac';
-  $MACH1='bigmac';
-  $MACH2='bigmac:2';
-  $MACH3='bigmac:4';
   $CASE10 = 0;
-  unlink 'cluster1','cluster2','cluster4';
-        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-        print FILE $MACH1;
-        close (FILE);
-        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
-        print FILE $MACH2;
-        close (FILE);
-        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
-        print FILE $MACH3;
-        close (FILE);
-        }
+}
 #-----------------------------------
 # For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
 elsif ($MACH eq 'bigmac-gcc44') {
@@ -362,6 +359,15 @@ elsif ($MACH eq 'bigmac-gcc44') {
 }
 #-----------------------------------
 # For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
+elsif ($MACH eq 'bigmac-gcc47') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/opt/openmpi16_gcc47/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $CASE10 = 0;
+}
+#-----------------------------------
+# For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
 elsif ($MACH eq 'bigmac-g95') {
   $MPICH = 2;
   $OPENMPI = 1;
@@ -425,6 +431,15 @@ elsif ($MACH eq 'green-g95') {
   $CASE10 = 0;
 }
 #-----------------------------------
+# For the  DELL cluster "green-intel11" with biprocs Quad-Core Xeon 2.6Ghz (8Gb RAM) per node
+elsif ($MACH eq 'green-intel11') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/home/pcpm/buildbot/openmpi_intel11/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $CASE10 = 0;
+}
+#-----------------------------------
 # For the AMD SUN GALAXY X4200  "chum" 2 x AMD 2220 Dual Cores with OpenMPI or MPICH2
 elsif ($MACH =~ /^chum-?(.*)/) {
   $MPICH = 2;
@@ -476,6 +491,143 @@ elsif ($MACH eq 'buda_mpich2') {
   $CASE10 = 0;
         }
 #-----------------------------------
+# For the  2 x  Intel Core2 Quad CPU 3GHz / 8GB  gcc451 + mpich2-1.3.2
+# Windows 7
+elsif ($MACH eq 'woopy') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -localonly';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  Intel Core i7 3.2GHz / 12Gb gcc462 + openmpi 1.4.3
+elsif ($MACH eq 'petrus') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/lib64/mpi/gcc/openmpi/bin";
+  $MPIRUN_NP = '/usr/lib64/mpi/gcc/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  Intel Core i7 3.4GHz / 8Gb gcc4.7.2+ openmpi 1.6.3
+# CentOS 6.3 packages for openmpi and gcc + fttw3 3.3.3 
+elsif ($MACH eq 'yquem') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  AMD FX-8120 3.1GHz / 8Gb gcc470 + openmpi 1.6.0
+elsif ($MACH eq 'vishnu') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Xeon Quad CPU 2.93GHz / 12GB  ifort 12.1.4 + openMPI 1.5.4
+elsif ($MACH eq 'tikal-ifort12') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_ifort12/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_ifort12/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Xeon Quad CPU 2.93GHz / 12GB  8GB  pgi 12.x + openMPI 1.6.2
+elsif ($MACH eq 'tikal-pgi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_pgi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_pgi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Xeon Quad CPU 2.93GHz / 12GB  8GB  psc + openMPI 1.4.3
+elsif ($MACH eq 'tikal') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Core2 Quad CPU 3GHz / 8GB  psc + openMPI 1.4.3
+elsif ($MACH eq 'tikal-openmp') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_ifort12/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_ifort12/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  AMD Opteron 2 x OctaCore CPU 2.6GHz / 16GB  open64 + openMPI 1.4.3
+elsif ($MACH eq 'max2-open64') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_open64/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_open64/bin/mpirun -np';
+  $CASE10 = 1;
+        }
+#-----------------------------------
+# For the  2 x  AMD Opteron 2 x OctaCore CPU 2.6GHz / 16GB  gcc46 + openMPI 1.4.5
+elsif ($MACH eq 'max2-ifort12') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_ifort12/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_ifort12/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  AMD Opteron 2 x OctaCore CPU 2.6GHz / 16GB  gcc46 + openMPI 1.4.3
+elsif ($MACH eq 'max2-openmpi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 1;
+        }
+#-----------------------------------
+# For the  2 x  AMD Opteron 2 x OctaCore CPU 2.6GHz / 16GB  gcc46 + mpich2 1.3.1 with slurm support
+elsif ($MACH eq 'max2') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 1;
+        }
+#-----------------------------------
+# For the  2 x  AMD  16-Core CPU   gcc46 +  ???   (Jean-Michel, could you complete ?)
+elsif ($MACH eq 'cronos') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi/bin";
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Core2 Quad CPU 3GHz / 8GB  gcc46 + openMPI 1.5.4 rpm
+elsif ($MACH eq 'toum') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/lib64/openmpi/bin";
+  $MPIRUN_NP = '/usr/lib64/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x  Intel Core2 Quad CPU 3GHz / 8GB  ifort12 + openMPI 1.4.4
+elsif ($MACH eq 'toum-ifort12') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = "/usr/local/openmpi_intel/bin";
+  $MPIRUN_NP = '/usr/local/openmpi_intel/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the  1 x Intel Core2 Quad CPU 2.6GHz / 4GB  gcc451 + mpich2 + atlas
 elsif ($MACH eq 'littlebuda') {
   $MPICH = 2;
@@ -494,7 +646,7 @@ elsif ($MACH eq 'inca') {
   $CASE10 = 0;
         }
 #-----------------------------------
-# For the  1 x Intel Core2 Quad CPU 3GHz / 8GB  gcc451 + mpich2-1.3
+# For the HP Z400 1 x Six Xeon Nehalem 3.3GHz / 12GB gcc451 + mpich2-1.3.x
 elsif ($MACH eq 'shiva') {
   $MPICH = 2;
   $OPENMPI = 0;
@@ -547,7 +699,7 @@ elsif ($MACH eq 'buda-gcc44_openmpi') {
         }
 #
 #-----------------------------------
-# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc451 + openmpi 1.4.2
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc451 + openmpi 1.4.3
 elsif ($MACH eq 'buda-gcc45_openmpi') {
   $MPICH = 2;
   $OPENMPI = 1;
@@ -555,6 +707,14 @@ elsif ($MACH eq 'buda-gcc45_openmpi') {
   $CASE10 = 0;
         }
 #-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc472 + openmpi 1.4.2
+elsif ($MACH eq 'buda-gcc47_openmpi') {
+ $MPICH = 2;
+ $OPENMPI = 1;
+ $MPIRUN_NP = '/usr/local/openmpi_gcc47/bin/mpirun --mca btl tcp,self -np';
+ $CASE10 = 0;
+       }
+#-----------------------------------
 # For the Bull 2 x Quad Xeon Nehalem 3GHz / 12GB  gcc432 + openmpi 1.2.9
 elsif ($MACH eq 'testf-gcc43') {
   $MPICH = 2;
@@ -563,6 +723,14 @@ elsif ($MACH eq 'testf-gcc43') {
   $CASE10 = 0;
         }
 #-----------------------------------
+# For TITANE
+elsif ($MACH eq 'titane') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = 'mpirun -n';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the Bull 2 x Quad Xeon Nehalem 3GHz / 12GB gcc440 + openmpi 1.3.2
 elsif ($MACH eq 'testf-gcc44') {
   $MPICH = 2;
@@ -571,6 +739,22 @@ elsif ($MACH eq 'testf-gcc44') {
   $CASE10 = 0;
         }
 #-----------------------------------
+# For the Bull 2 x Quad Xeon Nehalem 3GHz / 12GB gcc471 + openmpi 1.6.1
+elsif ($MACH eq 'testf-gcc47') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi-gcc47/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the HP Z400 1 x Quad Xeon Nehalem 2.7GHz / 3GB open64 4.5.1 ( AMD version) + openmpi 1.4.4
+elsif ($MACH eq 'coba2-open64') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_open64/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the HP Z400 1 x Quad Xeon Nehalem 2.7GHz / 3GB gcc44 + openmpi 1.3.3
 elsif ($MACH eq 'coba2-gcc44') {
   $MPICH = 2;
@@ -587,6 +771,29 @@ elsif ($MACH eq 'coba2-intel11') {
   $CASE10 = 0;
         }
 #-----------------------------------
+# For the HP Z400 1 x Quad Xeon Nehalem 2.7GHz / 3GB intel12.1.4 + openmpi 1.6.0 + mkl +fftw3
+elsif ($MACH eq 'coba2-intel12') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_intel12/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the HMEM - CISM machine with nodes Quad 12Core Opteron@2.2GHz
+elsif ($MACH eq 'hmem') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi/1.4.3-intel/bin/mpirun --mca btl tcp,self -np';
+        }
+#-----------------------------------
+# For the  1 x Intel Core2 Quad CPU 3GHz / 8GB  gcc44 + openmpi 1.4.1 + fftw3 ( all deb packages )
+elsif ($MACH eq 'ktulu') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the HP integrity Itanium 4 processor in LLN
 elsif ($MACH eq 'chpit-gcc44') {
   $MPICH = 2;
@@ -599,7 +806,7 @@ elsif ($MACH eq 'chpit-gcc44') {
 elsif ($MACH eq 'chpit-intel11') {
   $MPICH = 2;
   $OPENMPI = 1;
-  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $MPIRUN_NP = '/usr/local/openmpi-1.4.3-intel-11.1/bin/mpirun -np';
   $CASE10 = 0;
         }
 #-----------------------------------
@@ -624,7 +831,7 @@ elsif ($MACH eq 'pwrg4') {
         close (FILE);
         }
 #-----------------------------------
-# For the cluster of PowerPC Mac OS X "max" with biprocs
+# For the cluster of PowerPC Mac OS X "max" with biprocs with gm ( Myrinet )
 elsif ($MACH eq 'max') {
   $MPICH = 2;
   $OPENMPI = 1;
@@ -634,8 +841,8 @@ elsif ($MACH eq 'max') {
   $MACH1='maxi2 slots=1 max_slots=1';
   $MACH2='maxi3 slots=1 max_slots=1';
   $MACH3='maxi4 slots=1 max_slots=1';
-  $CASE10 = 0;
-  unlink 'cluster1','cluster2','cluster4';
+  $CASE10 = 1;
+  unlink 'cluster1','cluster2','cluster4','cluster10';
         open (FILE,">cluster1") || die "Unable to open FILE cluster1";
         print FILE $MACH0;
         close (FILE);
@@ -649,7 +856,23 @@ elsif ($MACH eq 'max') {
         print FILE $MACH2;
         print FILE $MACH3;
         close (FILE);
-        }
+        open (FILE,">cluster10") || die "Unable to open FILE cluster10";
+        print FILE 'maxi1 slots=1 max_slots=1';
+        print FILE 'maxi2 slots=1 max_slots=1';
+        print FILE 'maxi3 slots=1 max_slots=1';
+        print FILE 'maxi4 slots=1 max_slots=1';
+        print FILE 'maxi5 slots=1 max_slots=1';
+        print FILE 'maxi7 slots=1 max_slots=1';
+        print FILE 'maxi8 slots=1 max_slots=1';
+        print FILE 'maxi9 slots=1 max_slots=1';
+        print FILE 'maxi10 slots=1 max_slots=1';
+        print FILE 'maxi11 slots=2 max_slots=2';
+        print FILE 'maxi12 slots=2 max_slots=2';
+        print FILE 'maxi13 slots=2 max_slots=2';
+        print FILE 'maxi14 slots=2 max_slots=2';
+        print FILE 'maxi15 slots=2 max_slots=2';
+        close (FILE);
+   }
 #-----------------------------------
 # For the cluster of PowerPC Mac OS X "max" with biprocs
 elsif ($MACH eq 'max-eth') {
@@ -690,7 +913,7 @@ elsif ($MACH eq 'generic') {
  $MPIRUN_NP = 'mpirun -np ';
         }
 elsif ($MACH eq 'cea') {
- $MPIRUN_NP = 'cea_mprun -p parallele_128 -n  ';
+ $MPIRUN_NP = 'cea_mprun -n  ';
         }
 #-----------------------------------
 # config
@@ -699,6 +922,8 @@ elsif ($MACH eq 'config') {
  $MPIRUN_NP = "$config_mpirun -np ";
  $CASE4     = 0;
  $CASE10    = 0;
+ $CASE24    = 0;
+ $CASE32    = 0;
         }
 #-----------------------------------
 # For win32_mpich2 i.e. Windows32 with cygwin and mpich2-1.3 (on cauac)
@@ -712,6 +937,14 @@ elsif ($MACH eq 'test') {
  $MPIRUN_NP = ' ';
         }
 #-----------------------------------
+# For the hmem cluster, plain openmpi launch
+elsif ($MACH eq 'hmem') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = 'mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 else {
   print "The machine name $MACH is not allowed";
   print "Choose among : @MachList";
@@ -728,8 +961,9 @@ if ($hitreport) {
         print "Will make report";
         }
 else {
-        $hitnum = m/[A-Z]/;	# check for upper case
-        $hitrng = m/([A-Z])-(.*)/;	# check for range
+        $hitnum = m/[A-Z]{1,2}/;	# check for upper case
+        $hitrng = m/([A-Z]{1,2})-(.*)/;	# check for range
+        $hit_tutoparal_dfpt = m/dfpt_0[1-4]/;	# check for number between 01 and 04
         if ($hitrng) {
 	        $FirstSet = $1;
 	        $LastSet = $2;
@@ -739,19 +973,23 @@ else {
 	        $FirstSet = $ARGV[2];
 	        $LastSet = $ARGV[2];
 	        }
+        elsif ($hit_tutoparal_dfpt) {       # if last set is omitted, run only first one
+                $FirstSet = $ARGV[2];
+                $LastSet = $ARGV[2];
+                }
         else {
 	        print "Invalid sets: $ARGV[2]";
 	        exit 24;
 	        }
 # set label for default first and last test number
         $FirstCase = '1';
-        $LastCase = '10';
+        $LastCase = '32';
         $_ = $ARGV[3];
         $hit = m/(.*)-(.*)/;	# check for range
 	        if ($hit) {
 		        $FirstCase = $1;
 		        $LastCase = $2;
-		        $LastCase = '10' if ($LastCase eq 'end');
+		        $LastCase = '32' if ($LastCase eq 'end');
 		        }
 	        elsif ($ARGV[3] ne '') {	# if last test is omitted, run only first one
 		        $FirstCase = $ARGV[3];
@@ -788,8 +1026,33 @@ if ($hitreport) {
 
 # **************************************** 
 # Loop on all the sets
-for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
-        last if ($T1 eq 'AA');
+#
+if ( $TESTDIR eq 'paral') {
+        $CASE24=0;
+        $CASE32=0;
+}
+if ( $TESTDIR eq 'mpiio') {
+        $CASE10=0;
+        $CASE24=0;
+        $CASE32=0;
+}
+if ( $TESTDIR eq 'tutoparal') {
+        $CASE0=0 ;
+        $CASE1=0 ;
+        $CASE2=0 ;
+        $CASE4=0 ;
+        $CASE10=0;
+}
+#
+foreach $set (@Sets) {
+# Jump to first test to be run
+        next if ($T1 eq '' && $set ne $FirstSet);
+        last if ($T1 eq $LastSet);
+        $T1 = $set ;
+        print "Make test set $T1" ;
+
+#for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
+#        last if ($T1 eq 'ZZ');
 # Make preliminary operations that might differ for different tests
 
 # HERE, the set of possible tests and corresponding input file
@@ -816,18 +1079,18 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 	elsif ($T1 eq 'F') {
 	  $PSP1 = "$PSPS/13al.pspgth";
           $PSP2 = "$PSPS/33as.SGS_mod";
-		unlink 'tF.i_DS1_DEN','tF.i_DS2_DEN';
-	  system("$COPY_COMMAND tC1.o_DEN tF.i_DS1_DEN"); 
-	  system("$COPY_COMMAND tC1.o_DEN tF.i_DS2_DEN"); 
+          unlink 'tFi_DS1_DEN','tFi_DS2_DEN';
+	  system("$COPY_COMMAND tC1o_DEN tFi_DS1_DEN"); 
+	  system("$COPY_COMMAND tC1o_DEN tFi_DS2_DEN"); 
 	  }
 #
 	elsif ($T1 eq 'G') {
 	  $PSP1 = "$PSPS/13al.pspgth";
           $PSP2 = "$PSPS/33as.SGS_mod";
 	  $OPTFLDIFF = '-medium';
-	  unlink 'tG.i_WFK','tG.i_WFQ';
-	  system("$COPY_COMMAND tC1.o_WFK tG.i_WFK");
-	  system("$COPY_COMMAND tC1.o_WFK tG.i_WFQ");
+	  unlink 'tGi_WFK','tGi_WFQ';
+	  system("$COPY_COMMAND tC1o_WFK tGi_WFK");
+	  system("$COPY_COMMAND tC1o_WFK tGi_WFQ");
 	  }
 #
 	elsif ($T1 eq 'I') {
@@ -844,7 +1107,7 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
           $PSP1 = "$PSPS/41nb_001023.pspfhi";
           $PSP2 = "$PSPS/03li.pspfhi";
           $PSP3 = "$PSPS/08o_001023.pspfhi";
-          $OPTFLDIFF = '-medium';
+          $OPTFLDIFF = '-easy';
           }
 #
         elsif ($T1 eq 'M') {
@@ -880,7 +1143,7 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 #This is to test MPI and paral_kgb, only with 4 procs in parallel, paw case
         elsif ($T1 eq 'R') {
           $PSP1 = "$PSPS/6c_lda.paw";
-          $OPTFLDIFF = '-easy';
+          $OPTFLDIFF = '-ridiculous';
           $CASE1= 0;
           $CASE2= 0;
           $CASE10=0;
@@ -948,10 +1211,90 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
           $PSP1 = "$PSPS/31ga.pspnc";
           $PSP2 = "$PSPS/33as.pspnc";
           $OPTFLDIFF = '-medium';
-
           $PSP1 = "$PSPS/7n.psphgh";
           }
-	
+#PAW Berrys Phase calculation of Born effective charge in AlAs
+        elsif ($T1 eq 'AA') {
+          $PSP1 = "$PSPS/al_ps.abinit.paw";
+          $PSP2 = "$PSPS/as_ps.paw";
+	  $CASE10=0;
+          $OPTFLDIFF = '-easy';
+          }
+#Electron-phonon renormalization of the electronic eigenenergies
+        elsif ($T1 eq 'AB') {
+          $PSP1 = "$PSPS/6c.pspnc";
+          }
+#String method
+        elsif ($T1 eq 'AC') {
+          $PSP1 = "$PSPS/1h.pspnc";
+          $PSP2 = "$PSPS/1h.pspnc";
+          }
+#Parallelization over spinorial components
+        elsif ($T1 eq 'AD') {
+          $PSP1 = "$PSPS/83bi.paw";
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#Automatic Parallelization
+        elsif ($T1 eq 'AE') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }    
+#Parallelization of SC DMFT over k-points
+        elsif ($T1 eq 'AF') {
+          $PSP1 = "$PSPS/28ni.paw";
+          $PSP2 = "$PSPS/8o.2.paw";
+	  $OPTFLDIFF = '-medium';
+          $CASE2= 0;
+#          $CASE10=0;
+          }
+#Parallelization of NSC DMFT over bands and k-point
+        elsif ($T1 eq 'AG') {
+          $PSP1 = "$PSPS/28ni.paw";
+          $PSP2 = "$PSPS/8o.2.paw";
+	  $OPTFLDIFF = '-medium';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#Automatic Parallelization with unoccupied processor
+        elsif ($T1 eq 'AH') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#Parallelization on perturbations
+        elsif ($T1 eq 'AI') {
+          $PSP1 = "$PSPS/31ga.SGS_mod";
+          $PSP2 = "$PSPS/33as.SGS_mod";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+           }
+#Tutorial Parallelism : automatic testing dfpt 03, BaTiO3 ground state calculation
+        elsif ($T1 eq 'dfpt_03') {
+          $PSP1 = "$PSPS/56ba.psp_mod";
+          $PSP2 = "$PSPS/22ti.psp_mod";
+          $PSP3 = "$PSPS/8o.psp_mod";
+          $CASE32= 0;
+          }
+#Tutorial Parallelism : automatic testing dfpt 04, BaTiO3 linear response calculation
+        elsif ($T1 eq 'dfpt_04') {
+          $PSP1 = "$PSPS/56ba.psp_mod";
+          $PSP2 = "$PSPS/22ti.psp_mod";
+          $PSP3 = "$PSPS/8o.psp_mod";
+          $OPTFLDIFF = '-medium';
+          $CASE24= 0;
+          unlink 'tdfpt_04i_WFK','tdfpt_04i_WFQ';
+          system("$COPY_COMMAND tdfpt_0324o_WFK tdfpt_04i_WFK");
+          system("$COPY_COMMAND tdfpt_0324o_WFK tdfpt_04i_WFQ");
+          }
+
 # ****************************************
 	foreach $case (@Cases) {
 # Jump to first test to be run
@@ -961,7 +1304,8 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 		$T2 = $case;
 		if ( ($T2 eq '0' && $CASE0 == 0) || ($T2 eq '1' && $CASE1 == 0) || 
                      ($T2 eq '2' && $CASE2 == 0) || ($T2 eq '4' && $CASE4 == 0) || 
-		     ($T2 eq '10' && $CASE10 == 0) ) {
+		     ($T2 eq '10' && $CASE10 == 0) || ($T2 eq '24' && $CASE24 == 0) ||
+                     ($T2 eq '32' && $CASE32 == 0)  ) {
 			last if ($T2 eq $LastCase); 
 			next;
 			}
@@ -970,14 +1314,16 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 		$MODE = $T2 eq '0' ? 'SEQ' : 'PAR';
 		$CLUST = "../cluster$T2";
 		$NPAR = $T2;
+		$APPENDI = "i";
+		$APPENDO = "o";
 		unlink $RUNfile;
 		system ("$ERASE_COMMAND t$T1$T2*");	# unlink with metachar
 #Initialize the files file
 		open (FILE,">$RUNfile") || die "Unable to open FILE $RUNfile";
-		print FILE "$abinit_inpdir/$TESTDIR/Input/t$T1.in";
+		print FILE "$CYGWIN$abinit_inpdir/$TESTDIR/Input/t$T1.in";
 		print FILE "t$T1$T2.out";
-		print FILE "t$T1.i";
-		print FILE "t$T1$T2.o";
+		print FILE "t$T1$APPENDI";
+		print FILE "t$T1$T2$APPENDO";
 		print FILE "t$T1$T2";
 		print FILE $PSP1;
 		print FILE $PSP2;
@@ -986,6 +1332,12 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 #Run the job
 		if ($MACH eq 'max') {
 			$MachFile = "--hostfile $CLUST";
+   			# problem with DS5 of test E ( see below for reporting )
+			if ($T2 eq '10' && $T1 eq 'E') { $NPAR = 16; };
+			}
+		elsif ( $MACH =~ /^max2/ ) { 
+   			# problem with DS5 of test E ( see below for reporting )
+			if ($T2 eq '10' && $T1 eq 'E') { $NPAR = 16; };
 			}
 		elsif ($MPICH == 1 && $MODE eq 'PAR') { 
 			$MachFile = "-machinefile $CLUST";
@@ -1035,6 +1387,14 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 			$CALL_CODE = $MACH eq 'ibm6' ? "$MPIRUN_NP $CODE_PAR $MachFile -procs $NPAR" : "$MPIRUN_NP $NPAR $MachFile $CODE_PAR";
 			$CALL_CODE = $timeout_cmd.$CALL_CODE;
 			}
+   		# reset the $NPAR to 10 for reporting -> tE10.out
+                if ($MACH eq 'max') {
+                        if ($NPAR eq '16') { $NPAR = 10; };
+                }       
+                if ($MACH =~ /^max2/) {
+                        if ($NPAR eq '16') { $NPAR = 10; };
+                }       
+		#
 		$cmd = "$CALL_CODE < $RUNfile > t$T1$T2.log";
 		print $cmd if ($debug > 1);
 		system($cmd);
@@ -1111,8 +1471,12 @@ sub doreport {
 # Prepare filenames
         $fn1 = "$abinit_inpdir/$TESTDIR/Input/report.in";
         $reportref = &transpath($fn1);
-        $fn2 = "fldiff.*.report" ;
+        $fn2 = "fldiff.set?.report" ;
         $fldiffreport = &transpath($fn2);
+        $fn2b = "fldiff.set??.report" ;
+        $fldiffreportb = &transpath($fn2b);
+        $fn2c = "fldiff.set???*.report" ;
+        $fldiffreportc = &transpath($fn2c);
         $fn3 = "summaryfldiff" ;
         $summaryfldiff = &transpath($fn3);
         $fn4 = "report" ;
@@ -1120,6 +1484,8 @@ sub doreport {
 # Create summary of tests
         unlink($summaryfldiff);
         system ("grep --no-filename 'Summary' $fldiffreport > $summaryfldiff");
+        system ("grep --no-filename 'Summary' $fldiffreportb >> $summaryfldiff");
+        system ("grep --no-filename 'Summary' $fldiffreportc >> $summaryfldiff");
 # Compare with reference files
         print "Prepare the short report";
         unlink($shortreport);
